@@ -43,11 +43,9 @@ KWalletPopup::KWalletPopup(const QString &wallet, QWidget *parent, const QString
     if (!ul.isEmpty()) {
         auto pm = new QMenu(this);
         pm->setObjectName(QStringLiteral("Disconnect Apps"));
-        int id = 7000;
         for (QStringList::const_iterator it = ul.begin(), end(ul.end()); it != end; ++it) {
             QAction *a = pm->addAction(*it, this, &KWalletPopup::disconnectApp);
             a->setData(*it);
-            id++;
         }
         QAction *act = addMenu(pm);
         act->setText(i18n("Disconnec&t"));
